% function [f,g,H] = Frosenbrock(X,a) Rosenbrock's function in 2D
%
% Rosenbrock's function (for a = 100) is an optimization benchmark in 2D:
%
%   f(x) = a.(x2-x1) + (1-x1)
%
% In:
%   X: Nx2 list of row vectors.
%   a: real number. Default: 100.
% Out:
%   f: Nx1 list of function values.
%   g: Nx2 list of gradient vectors.
%   H: 2x2xN list of Hessian matrices.

% Copyright (c) 2005 by Miguel A. Carreira-Perpinan

function [f,g,H] = Frosenbrock(X,a)

% ---------- Argument defaults ----------
if ~exist('a','var') | isempty(a) a = 100; end;
% ---------- End of "argument defaults" ----------

N = size(X,1); X1 = X(:,1); X2 = X(:,2);

f = a*(X2-X1.^2).^2 + (1-X1).^2;

if nargout > 1
  g = [-4*a*X1.*(X2-X1.^2)-2*(1-X1) 2*a*(X2-X1.^2)];
  if nargout > 2
    H = zeros(2,2,N);
    H(1,1,:) = -4*a*(-3*X1.^2+X2)+2;
    H(1,2,:) = -4*a*X1; H(2,1,:) = H(1,2,:);
    H(2,2,:) = 2*a;
  end
end

